/********************************************************************
 * \file
 * implementacja kolejki FIFO dla wysylki danych poprzez USB
 * cel: umozliwienie kilkakrotnego wywolywania procedury wysylki
 * w trakcie jednego obiegu petli glownej
 * (ominiecie ograniczenia firmware Microchipa)
 * \author Tomasz Ostrowski
 * ot (at) epf (dot) pl
 ********************************************************************/

#include "user\usbFIFO.h"
#define QUEUE_SIZE 196
unsigned char queue[QUEUE_SIZE];   //tablica kolejki
unsigned char inp=0, out=0;

void usbFIFO_push(unsigned char input)
{
    queue[inp] = input;     //wrzucenie elementu do kolejki
    inp = (inp + 1) % QUEUE_SIZE;  //aktualizacja wskaznika wejscia
}

//push string
void usbFIFO_pushS(char* s)
{
    unsigned char i = 0;
    while( *s )
    {
        queue[inp] = *s;     //wrzucenie elementu do kolejki
        inp = (inp + 1) % QUEUE_SIZE;  //aktualizacja wskaznika wejscia
        s++;                //increment pointer
    }
}

//funkcja wrzuca do FIFO n bajtow
void usbFIFO_pushN(char* s, int n)
{
    unsigned char i=0;
    while(i<n)
    {
        queue[inp] = s[i];    //wrzucenie elementu do kolejki
        inp = (inp + 1) % QUEUE_SIZE;
        i++;
    }
}


unsigned char usbFIFO_remove(void)
{
    unsigned char x;
    x = queue[out];
    out = (out + 1) % QUEUE_SIZE;
    return(x); 
}

//funkcja zwraca wartosc niezerowa gdy FIFO jest puste
unsigned char usbFIFO_empty(void)
{
    if(out==inp) return 1;   //FIFO empty
    else return 0;          //FIFO not empty
}
